import { BuildConfig, CreateWebpackConfigOptions } from 'lib/runtime/server';
import TsconfigPathsPlugin from 'tsconfig-paths-webpack-plugin';
import webpack from 'webpack';
export declare const fileLoaderConfig: (buildConfig: BuildConfig) => {
    exclude: RegExp;
    loader: string;
    options: {
        name: string;
    };
    test: RegExp;
};
/**
 * Base webpack configuration that is shared by the server and the client
 * - load original source maps from custom SWM dependencies
 * - compile TypeScript to JavaScript
 * - handle static files (images and fonts)
 */
declare function baseConfig(options: CreateWebpackConfigOptions): {
    module: {
        rules: ({
            exclude: RegExp;
            loader: string;
            options: {
                name: string;
            };
            test: RegExp;
        } | {
            test: RegExp;
            use: ({
                loader: string;
                options: {
                    workers: number;
                };
            } | {
                loader: string;
                options: {
                    happyPackMode: boolean;
                    transpileOnly: boolean;
                };
            } | {
                loader: string;
                options: {
                    cacheDirectory: string;
                };
            })[];
            loader?: undefined;
            options?: undefined;
        } | {
            loader: string;
            options: {
                name: string;
            };
            test: RegExp;
            use?: undefined;
        } | {
            loader: string;
            test: RegExp;
            use?: undefined;
            options?: undefined;
        })[];
    };
    plugins: webpack.NoEmitOnErrorsPlugin[];
    resolve: {
        extensions: string[];
        plugins: TsconfigPathsPlugin[];
        symlinks: boolean;
    };
};
export default baseConfig;
