"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var assets_webpack_plugin_1 = tslib_1.__importDefault(require("assets-webpack-plugin"));
var fs_1 = tslib_1.__importDefault(require("fs"));
var html_webpack_plugin_1 = tslib_1.__importDefault(require("html-webpack-plugin"));
var path_1 = tslib_1.__importDefault(require("path"));
var server_1 = require("../runtime/server");
var assets_1 = require("../runtime/server/assets");
var getPlugins = function (buildConfig) { return [
    new assets_webpack_plugin_1.default({
        filename: path_1.default.relative(process.cwd(), server_1.getAssetsFile(buildConfig.OUTPUT)),
        processOutput: function (assets) {
            assets_1.updateAssetLocations(assets);
            return JSON.stringify(assets);
        },
    }),
]; };
/**
 * Base webpack config for the client that is used both in development and production
 * - Compile SCSS to CSS and extract into external assets
 * - Create assets.json that maps the created assets to their locations
 * - Create vendor chunk with everything from node_modules except for SWM modules
 */
var clientBaseConfig = function (options) {
    var _a = options.buildConfig, CLIENT_ENTRY = _a.CLIENT_ENTRY, OUTPUT = _a.OUTPUT, CLIENT_POLYFILLS = _a.CLIENT_POLYFILLS, PUBLIC_PATH = _a.PUBLIC_PATH, SERVER_PUBLIC_DIR = _a.SERVER_PUBLIC_DIR;
    var mainEntry = [CLIENT_ENTRY];
    /*
        https://github.com/webpack/webpack/issues/6647
        You should not have a entrypoint for vendor. It's not an entry.
        If you want to run two modules in order at an entrypoint, use an array.
    */
    if (CLIENT_POLYFILLS && fs_1.default.existsSync(CLIENT_POLYFILLS)) {
        mainEntry = [CLIENT_POLYFILLS, CLIENT_ENTRY];
    }
    var entry = {
        main: mainEntry,
    };
    var plugins = getPlugins(options.buildConfig);
    if (SERVER_PUBLIC_DIR) {
        var indexHtml = path_1.default.resolve(SERVER_PUBLIC_DIR, 'index.html');
        if (fs_1.default.existsSync(indexHtml)) {
            plugins.push(new html_webpack_plugin_1.default({
                inject: true,
                template: indexHtml,
            }));
        }
    }
    return {
        entry: entry,
        module: {
            rules: [],
        },
        optimization: {
            splitChunks: {
                cacheGroups: {
                    vendor: {
                        chunks: 'all',
                        name: 'vendor',
                        priority: -20,
                        test: function (module) {
                            if (!module.context) {
                                return false;
                            }
                            var modulePos = module.context.indexOf('node_modules');
                            if (modulePos === -1) {
                                return false;
                            }
                            var isWatchtower = module.context.indexOf('project-watchtower', modulePos) !== -1;
                            return !isWatchtower;
                        },
                    },
                },
            },
        },
        output: {
            path: OUTPUT,
            publicPath: PUBLIC_PATH,
        },
        plugins: plugins,
    };
};
exports.default = clientBaseConfig;
//# sourceMappingURL=webpack.client.js.map