/// <reference types="node" />
import { ChildProcess } from 'child_process';
import * as buildModule from './build';
import * as configModule from './config';
import * as runtimeServerModule from './runtime/server';
import * as universalModule from './runtime/universal';
import * as serverModule from './server';
import * as statsModule from './stats';
import { Logger } from 'typescript-log';
import { BuildConfig } from './runtime/server';
import { BuildParam, StartParam, WatchParam } from './types';
export * from './types';
export declare type BinPromiseType = (log: Logger, buildConfig: BuildConfig, ...args: string[]) => Promise<any>;
export interface BinType {
    build: (log: Logger, buildConfig: BuildConfig, ...args: BuildParam[]) => Promise<any>;
    clean: BinPromiseType;
    exploreBundle: BinPromiseType;
    start: (log: Logger, buildConfig: BuildConfig, startEnv: NodeJS.ProcessEnv, ...args: StartParam[]) => Promise<ChildProcess>;
    stats: BinPromiseType;
    watch: (log: Logger, buildConfig: BuildConfig, watchProcessEnv: NodeJS.ProcessEnv, ...args: WatchParam[]) => Promise<any>;
}
export declare const bin: BinType;
export declare const build: typeof buildModule;
export declare const config: typeof configModule;
export declare const runtimeServer: typeof runtimeServerModule;
export declare const universal: typeof universalModule;
export declare const server: typeof serverModule;
export declare const stats: typeof statsModule;
export { default as clean } from './clean';
