"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var fs_1 = tslib_1.__importDefault(require("fs"));
var path_1 = tslib_1.__importDefault(require("path"));
var assets_1 = require("../assets");
var full_render_1 = require("../ssr/full-render");
var render_html_1 = require("../ssr/helpers/render-html");
var isProduction = process.env.NODE_ENV === 'production';
exports.expressNoop = function (_res, _req, next) { return next(); };
exports.getDefaultHtmlMiddleware = function (log, runtimeConfig) {
    // on production we just serve the generated index.html
    if (isProduction) {
        var indexPath_1 = path_1.default.resolve(runtimeConfig.BASE, 'index.html');
        var indexFileMissing_1 = !fs_1.default.existsSync(indexPath_1);
        var loggedMissingIndexFileError_1 = false;
        var productionMiddleware = function (_req, res) {
            // We only log the error if we hit this middleware
            // if the consumer has registered their own SSR middleware we will
            // never use this, so no need to log an error
            if (indexFileMissing_1) {
                if (!loggedMissingIndexFileError_1) {
                    log.error('Cannot find index.html file to serve, default watchtower middleware will return 404');
                    loggedMissingIndexFileError_1 = true;
                }
                return res.status(404);
            }
            return res.status(200).sendFile(indexPath_1);
        };
        return productionMiddleware;
    }
    // for development we grab the source index.html and add the assets
    var indexContent;
    if (runtimeConfig.SERVER_PUBLIC_DIR) {
        var indexPath = path_1.default.resolve(runtimeConfig.SERVER_PUBLIC_DIR, 'index.html');
        if (fs_1.default.existsSync(indexPath)) {
            indexContent = fs_1.default.readFileSync(indexPath, 'utf8');
        }
    }
    var middleware = function (req, res) {
        var buildAssets = assets_1.getAssets(runtimeConfig);
        if (indexContent) {
            var withHeadTags = indexContent.replace('</head>', assets_1.getHeadAssets(buildAssets)
                .map(function (headAsset) { return headAsset.tag; })
                .join('\n') + "\n    </head>");
            var withBodyTags = withHeadTags.replace('</body>', assets_1.getBodyAssets(buildAssets)
                .map(function (bodyAsset) { return bodyAsset.tag; })
                .join('\n') + "\n    </body>");
            return res
                .status(200)
                .contentType('text/html')
                .send(withBodyTags);
        }
        var indexWithAssets = render_html_1.renderHtml({
            context: {
                promiseTracker: new full_render_1.PromiseTracker(),
                ssrRequestProps: {},
            },
            head: undefined,
            pageTags: {
                body: assets_1.getBodyAssets(buildAssets),
                head: assets_1.getHeadAssets(buildAssets),
            },
            renderResult: '',
            req: req,
        });
        return res
            .status(200)
            .contentType('text/html')
            .send(indexWithAssets);
    };
    return middleware;
};
//# sourceMappingURL=default-html-middleware.js.map