"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var PromiseTracker = /** @class */ (function () {
    function PromiseTracker() {
        this.waitIndex = 1;
        this.promises = {};
    }
    PromiseTracker.prototype.track = function (promise) {
        var currentWaitIndex = this.waitIndex;
        if (!this.promises[currentWaitIndex]) {
            this.promises[currentWaitIndex] = [];
        }
        // Because we are buffering promises for later
        // we need to catch any failures synchronously.
        // if we don't, we will get warnings about handling promises
        // asynchronously.
        if (promise.catch) {
            // tslint:disable-next-line:no-empty
            ;
            promise.catch(function () { });
        }
        this.promises[currentWaitIndex].push(promise);
    };
    PromiseTracker.prototype.middleware = function () {
        var _this = this;
        return function () { return function (next) { return function (action) {
            var result = next(action);
            // Promise.resolve must return the same promise if the arg is a promise
            // http://www.ecma-international.org/ecma-262/6.0/#sec-promise.resolve
            if (Promise.resolve(result) === result) {
                _this.track(result);
            }
            return result;
        }; }; };
    };
    PromiseTracker.prototype.hasWork = function () {
        if (!this.promises[this.waitIndex]) {
            return false;
        }
        return this.promises[this.waitIndex].length > 0;
    };
    PromiseTracker.prototype.waitForCompletion = function () {
        if (!this.hasWork()) {
            return Promise.resolve();
        }
        var all = Promise.all(this.promises[this.waitIndex++].slice())
            // Use setTimeout to put the resolution of this
            //  promise back onto the event loop, this can fix
            //  issues where tests have not re-rendered before
            //  trying to find elements
            .then(function () { return new Promise(function (resolve) { return setTimeout(resolve, 0); }); });
        return all;
    };
    return PromiseTracker;
}());
exports.PromiseTracker = PromiseTracker;
//# sourceMappingURL=promise-tracker.js.map