"use strict";
var _this = this;
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var path_1 = tslib_1.__importDefault(require("path"));
var server_1 = require("../runtime/server");
var fs_1 = require("../runtime/util/fs");
var getChunkSize = function (log, runtimeConfig, chunkPath) { return tslib_1.__awaiter(_this, void 0, void 0, function () {
    var absolutePath, size;
    return tslib_1.__generator(this, function (_a) {
        switch (_a.label) {
            case 0:
                absolutePath = server_1.getAbsoluteAssetPath(runtimeConfig, chunkPath);
                return [4 /*yield*/, fs_1.getFileSize(log, absolutePath)];
            case 1:
                size = _a.sent();
                return [2 /*return*/, { kb: fs_1.formatFileSize(size), bytes: Math.round(size) }];
        }
    });
}); };
var bundleSize = function (log, runtimeConfig) { return tslib_1.__awaiter(_this, void 0, void 0, function () {
    var assetFilePath, assetFile, assets_1, jsAssets, cssAssets, totalJs_1, totalCss_1, values, stats, e_1;
    return tslib_1.__generator(this, function (_a) {
        switch (_a.label) {
            case 0:
                _a.trys.push([0, 3, , 4]);
                assetFilePath = path_1.default.resolve(runtimeConfig.BASE, 'assets.json');
                return [4 /*yield*/, fs_1.readFile(log, assetFilePath)];
            case 1:
                assetFile = _a.sent();
                assets_1 = JSON.parse(assetFile);
                jsAssets = Object.keys(assets_1)
                    .filter(function (key) {
                    return !!assets_1[key].js;
                })
                    .map(function (key) {
                    return { js: assets_1[key].js, key: key };
                });
                cssAssets = Object.keys(assets_1)
                    .filter(function (key) {
                    return !!assets_1[key].css;
                })
                    .map(function (key) {
                    return { css: assets_1[key].css, key: key };
                });
                totalJs_1 = 0;
                totalCss_1 = 0;
                return [4 /*yield*/, Promise.all(jsAssets.map(function (jsAsset) {
                        return getChunkSize(log, runtimeConfig, jsAsset.js).then(function (size) {
                            totalJs_1 += size.bytes;
                            return {
                                asset: jsAsset.key + ".js",
                                size: size,
                            };
                        });
                    }).concat(cssAssets.map(function (cssAsset) {
                        return getChunkSize(log, runtimeConfig, cssAsset.css).then(function (size) {
                            totalCss_1 += size.bytes;
                            return {
                                asset: cssAsset.key + ".css",
                                size: size,
                            };
                        });
                    })))];
            case 2:
                values = _a.sent();
                stats = values.reduce(function (acc, val) {
                    acc["bundle_" + val.asset] = val.size.bytes.toFixed(0);
                    return acc;
                }, {});
                stats.total_js = totalJs_1.toFixed(0);
                stats.total_css = totalCss_1.toFixed(0);
                log.info(stats, 'Bundle size');
                return [2 /*return*/, stats];
            case 3:
                e_1 = _a.sent();
                log.error('Error measuring bundle sizes');
                return [2 /*return*/, {}];
            case 4: return [2 /*return*/];
        }
    });
}); };
exports.default = bundleSize;
//# sourceMappingURL=bundle-size.js.map