"use strict";
var _this = this;
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var path_1 = tslib_1.__importDefault(require("path"));
var config_1 = require("../runtime/config/config");
var fs_1 = require("../runtime/util/fs");
var bundle_size_1 = tslib_1.__importDefault(require("./bundle-size"));
var lighthouse_1 = require("./lighthouse");
var ssr_stats_1 = tslib_1.__importDefault(require("./ssr-stats"));
exports.measureBuildStats = function (log, buildConfig, verbose) { return tslib_1.__awaiter(_this, void 0, void 0, function () {
    var runtimeConfig, bundleMetrics, ssrMetrics, lighthouseMetrics;
    return tslib_1.__generator(this, function (_a) {
        switch (_a.label) {
            case 0:
                runtimeConfig = config_1.getRuntimeConfigFromBuildConfig(buildConfig);
                return [4 /*yield*/, bundle_size_1.default(log, runtimeConfig)];
            case 1:
                bundleMetrics = _a.sent();
                return [4 /*yield*/, ssr_stats_1.default(log, buildConfig, verbose)];
            case 2:
                ssrMetrics = _a.sent();
                return [4 /*yield*/, lighthouse_1.lighthouseStats(log, buildConfig, verbose)];
            case 3:
                lighthouseMetrics = _a.sent();
                return [2 /*return*/, tslib_1.__assign({}, bundleMetrics, ssrMetrics, lighthouseMetrics)];
        }
    });
}); };
exports.writeBuildStats = function (log, buildConfig, metrics) { return tslib_1.__awaiter(_this, void 0, void 0, function () {
    var keys, values, titleRow, valueRow, fileContent, statsFilePath;
    return tslib_1.__generator(this, function (_a) {
        switch (_a.label) {
            case 0:
                // TeamCity expects key-value pairs written to the console
                Object.keys(metrics).forEach(function (key) {
                    log.info("##teamcity[buildStatisticValue key='" + key + "' value='" + metrics[key] + "']");
                });
                keys = [];
                values = [];
                Object.keys(metrics).forEach(function (key) {
                    keys.push(key);
                    values.push(metrics[key]);
                });
                titleRow = keys.join(',');
                valueRow = values.join(',');
                fileContent = titleRow + '\n' + valueRow;
                statsFilePath = path_1.default.resolve(buildConfig.BASE, 'build-stats.csv');
                return [4 /*yield*/, fs_1.writeFile(log, statsFilePath, fileContent)];
            case 1:
                _a.sent();
                return [2 /*return*/];
        }
    });
}); };
exports.measureAndWriteBuildStats = function (log, buildConfig, verbose) {
    if (verbose === void 0) { verbose = false; }
    return tslib_1.__awaiter(_this, void 0, void 0, function () {
        var metrics;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, exports.measureBuildStats(log, buildConfig, verbose)];
                case 1:
                    metrics = _a.sent();
                    return [4 /*yield*/, exports.writeBuildStats(log, buildConfig, metrics)];
                case 2:
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    });
};
//# sourceMappingURL=index.js.map