"use strict";
var _this = this;
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var dotenv_1 = tslib_1.__importDefault(require("dotenv"));
var http_1 = tslib_1.__importDefault(require("http"));
var os_1 = tslib_1.__importDefault(require("os"));
var path_1 = tslib_1.__importDefault(require("path"));
var server_1 = require("../runtime/server/server");
var network_1 = require("../runtime/util/network");
var process_1 = require("../util/process");
var time_1 = require("../util/time");
var getIp = function () {
    var interfaces = os_1.default.networkInterfaces();
    for (var _i = 0, _a = Object.keys(interfaces); _i < _a.length; _i++) {
        var i = _a[_i];
        for (var _b = 0, _c = interfaces[i]; _b < _c.length; _b++) {
            var address = _c[_b];
            if (address.family === 'IPv4' && !address.internal) {
                return address.address;
            }
        }
    }
    return os_1.default.hostname();
};
var getServerUrl = function (port, urlPath) {
    var useUrlPath = urlPath.indexOf('/') === 0 ? urlPath : '/' + urlPath;
    var host = process.env.STATS_SERVER_ADDRESS || getIp() || 'localhost'; // provided by build environment, ref OPS-383
    return "http://" + host + ":" + port + useUrlPath;
};
exports.loadSSRPage = function (url) {
    return new Promise(function (resolve, reject) {
        var startTime = time_1.getTimeMs();
        var request = http_1.default.get(url, function (res) {
            res.setEncoding('utf8');
            var size = 0;
            var content = '';
            res.on('data', function (chunk) {
                size += chunk.length;
                content += chunk.toString();
            });
            res.on('end', function () {
                var time = time_1.getTimeMs() - startTime;
                resolve({ size: size, time: time, content: content });
            });
        });
        request.on('error', function (err) { return reject(err); });
    });
};
exports.runStatsOnServer = function (log, buildConfig, statsFn, verbose) {
    if (verbose === void 0) { verbose = false; }
    return tslib_1.__awaiter(_this, void 0, void 0, function () {
        var OUTPUT, HAS_SERVER, STATS_ENV, STATS_PAGES, port, serverEntryFile, devServer, _a, _b, _i, page, urlPath, url, i, err_1;
        return tslib_1.__generator(this, function (_c) {
            switch (_c.label) {
                case 0:
                    OUTPUT = buildConfig.OUTPUT, HAS_SERVER = buildConfig.HAS_SERVER, STATS_ENV = buildConfig.STATS_ENV, STATS_PAGES = buildConfig.STATS_PAGES;
                    if (!HAS_SERVER) {
                        log.info('Skipping server-based stats because the application has no server');
                        return [2 /*return*/];
                    }
                    dotenv_1.default.config({
                        path: path_1.default.join(buildConfig.BASE, '.env'),
                    });
                    return [4 /*yield*/, network_1.findFreePort(server_1.getPort(buildConfig.DEV_SERVER_PORT))];
                case 1:
                    port = _c.sent();
                    serverEntryFile = path_1.default.resolve(OUTPUT, 'server.js');
                    return [4 /*yield*/, process_1.forkPromise(log, serverEntryFile, [], {
                            env: tslib_1.__assign({ NODE_ENV: 'production' }, process.env, STATS_ENV, { PORT: port, PROJECT_DIR: buildConfig.BASE }),
                            silent: !verbose,
                        }, true)];
                case 2:
                    devServer = _c.sent();
                    _c.label = 3;
                case 3:
                    _c.trys.push([3, 13, 14, 15]);
                    return [4 /*yield*/, time_1.timeout(network_1.waitForConnection(port), 20000)];
                case 4:
                    _c.sent();
                    _a = [];
                    for (_b in STATS_PAGES)
                        _a.push(_b);
                    _i = 0;
                    _c.label = 5;
                case 5:
                    if (!(_i < _a.length)) return [3 /*break*/, 12];
                    page = _a[_i];
                    if (!STATS_PAGES.hasOwnProperty(page)) return [3 /*break*/, 11];
                    urlPath = STATS_PAGES[page];
                    url = getServerUrl(port, urlPath);
                    i = 0;
                    _c.label = 6;
                case 6:
                    if (!(i < 3)) return [3 /*break*/, 9];
                    return [4 /*yield*/, time_1.timeout(exports.loadSSRPage(url), 20000)];
                case 7:
                    _c.sent();
                    _c.label = 8;
                case 8:
                    i++;
                    return [3 /*break*/, 6];
                case 9: return [4 /*yield*/, statsFn({ page: page, urlPath: urlPath, url: url, port: port })];
                case 10:
                    _c.sent();
                    _c.label = 11;
                case 11:
                    _i++;
                    return [3 /*break*/, 5];
                case 12: return [3 /*break*/, 15];
                case 13:
                    err_1 = _c.sent();
                    throw err_1;
                case 14:
                    devServer.kill();
                    return [7 /*endfinally*/];
                case 15: return [2 /*return*/];
            }
        });
    });
};
//# sourceMappingURL=server.js.map