import * as tslib_1 from "tslib";
import { default as watchServer } from '../watch/server';
import build from './build';
import clean from './clean';
import start from './start';
/**
 * Rebuilds the client on changes
 * @param args
 * - server: Also watches and rebuilds server
 * - fast: disables type checking
 * - client: Only run client without a server
 */
const watch = (log, buildConfig, watchProcessEnv, ...args) => tslib_1.__awaiter(this, void 0, void 0, function* () {
    const { HAS_SERVER } = buildConfig;
    const additionalStartParams = [];
    const env = Object.assign({}, watchProcessEnv);
    if (args.indexOf('fast') !== -1) {
        additionalStartParams.push('fast');
        env.START_FAST_MODE = 'true';
    }
    yield clean(log, buildConfig);
    const isServerWatch = HAS_SERVER && args.indexOf('server') !== -1;
    if (isServerWatch) {
        return watchServer(log, buildConfig);
    }
    const clientMode = !HAS_SERVER || args.indexOf('client') !== -1;
    if (clientMode) {
        return start(log, buildConfig, env, 'watch', 'client', ...additionalStartParams);
    }
    else {
        yield build(log, buildConfig, 'server', 'dev');
        return start(log, buildConfig, env, 'watch', ...additionalStartParams);
    }
});
export default watch;
//# sourceMappingURL=watch.js.map