import * as tslib_1 from "tslib";
import util from 'util';
export const formatElapsed = (hrEnd) => {
    return util.format('%ds %dms', hrEnd[0], hrEnd[1] / 1000000);
};
export const functionTimer = (description, func, logger, logResult, 
/** Adds a category to the log object */
category) => {
    const startTime = process.hrtime();
    try {
        const result = func();
        const elapsed = process.hrtime(startTime);
        const elapsedTime = formatElapsed(elapsed);
        const logObj = {
            description,
            elapsed,
        };
        if (logResult) {
            logObj.result = logResult(result);
        }
        if (category) {
            logObj.category = category;
        }
        logger.debug(logObj, `${description} took ${elapsedTime}`);
        return result;
    }
    catch (err) {
        const elapsed = process.hrtime(startTime);
        const elapsedTime = formatElapsed(elapsed);
        const logObj = {
            description,
            elapsed,
            err,
        };
        if (category) {
            logObj.category = category;
        }
        logger.debug(logObj, `${description} threw after ${elapsedTime}`);
        throw err;
    }
};
export const functionTimerAsync = (description, func, logger, logResult, 
/** Adds a category to the log object */
category) => tslib_1.__awaiter(this, void 0, void 0, function* () {
    const startTime = process.hrtime();
    try {
        const result = yield func();
        const elapsed = process.hrtime(startTime);
        const elapsedTime = formatElapsed(elapsed);
        const logObj = {
            description,
            elapsed,
        };
        if (logResult) {
            logObj.result = logResult(result);
        }
        if (category) {
            logObj.category = category;
        }
        logger.debug(logObj, `Async ${description} took ${elapsedTime}`);
        return result;
    }
    catch (err) {
        const elapsed = process.hrtime(startTime);
        const elapsedTime = formatElapsed(elapsed);
        const logObj = { description, elapsed, err };
        if (category) {
            logObj.category = category;
        }
        logger.debug(logObj, `Async ${description} threw after ${elapsedTime}`);
        throw err;
    }
});
//# sourceMappingURL=function-timer.js.map