import * as tslib_1 from "tslib";
import path from 'path';
import { getAbsoluteAssetPath } from '../runtime/server';
import { formatFileSize, getFileSize, readFile } from '../runtime/util/fs';
const getChunkSize = (log, runtimeConfig, chunkPath) => tslib_1.__awaiter(this, void 0, void 0, function* () {
    const absolutePath = getAbsoluteAssetPath(runtimeConfig, chunkPath);
    const size = yield getFileSize(log, absolutePath);
    return { kb: formatFileSize(size), bytes: Math.round(size) };
});
const bundleSize = (log, runtimeConfig) => tslib_1.__awaiter(this, void 0, void 0, function* () {
    try {
        const assetFilePath = path.resolve(runtimeConfig.BASE, 'assets.json');
        const assetFile = yield readFile(log, assetFilePath);
        const assets = JSON.parse(assetFile);
        const jsAssets = Object.keys(assets)
            .filter(key => {
            return !!assets[key].js;
        })
            .map(key => {
            return { js: assets[key].js, key };
        });
        const cssAssets = Object.keys(assets)
            .filter(key => {
            return !!assets[key].css;
        })
            .map(key => {
            return { css: assets[key].css, key };
        });
        let totalJs = 0;
        let totalCss = 0;
        const values = yield Promise.all([
            ...jsAssets.map(jsAsset => getChunkSize(log, runtimeConfig, jsAsset.js).then(size => {
                totalJs += size.bytes;
                return {
                    asset: `${jsAsset.key}.js`,
                    size,
                };
            })),
            ...cssAssets.map(cssAsset => getChunkSize(log, runtimeConfig, cssAsset.css).then(size => {
                totalCss += size.bytes;
                return {
                    asset: `${cssAsset.key}.css`,
                    size,
                };
            })),
        ]);
        const stats = values.reduce((acc, val) => {
            acc[`bundle_${val.asset}`] = val.size.bytes.toFixed(0);
            return acc;
        }, {});
        stats.total_js = totalJs.toFixed(0);
        stats.total_css = totalCss.toFixed(0);
        log.info(stats, 'Bundle size');
        return stats;
    }
    catch (e) {
        log.error('Error measuring bundle sizes');
        return {};
    }
});
export default bundleSize;
//# sourceMappingURL=bundle-size.js.map