import * as tslib_1 from "tslib";
import path from 'path';
import { getRuntimeConfigFromBuildConfig } from '../runtime/config/config';
import { writeFile } from '../runtime/util/fs';
import bundleSize from './bundle-size';
import { lighthouseStats } from './lighthouse';
import ssrStats from './ssr-stats';
export const measureBuildStats = (log, buildConfig, verbose) => tslib_1.__awaiter(this, void 0, void 0, function* () {
    const runtimeConfig = getRuntimeConfigFromBuildConfig(buildConfig);
    const bundleMetrics = yield bundleSize(log, runtimeConfig);
    const ssrMetrics = yield ssrStats(log, buildConfig, verbose);
    const lighthouseMetrics = yield lighthouseStats(log, buildConfig, verbose);
    return Object.assign({}, bundleMetrics, ssrMetrics, lighthouseMetrics);
});
export const writeBuildStats = (log, buildConfig, metrics) => tslib_1.__awaiter(this, void 0, void 0, function* () {
    // TeamCity expects key-value pairs written to the console
    Object.keys(metrics).forEach(key => {
        log.info(`##teamcity[buildStatisticValue key='${key}' value='${metrics[key]}']`);
    });
    // Jenkins wants a CSV file
    const keys = [];
    const values = [];
    Object.keys(metrics).forEach(key => {
        keys.push(key);
        values.push(metrics[key]);
    });
    const titleRow = keys.join(',');
    const valueRow = values.join(',');
    const fileContent = titleRow + '\n' + valueRow;
    const statsFilePath = path.resolve(buildConfig.BASE, 'build-stats.csv');
    yield writeFile(log, statsFilePath, fileContent);
});
export const measureAndWriteBuildStats = (log, buildConfig, verbose = false) => tslib_1.__awaiter(this, void 0, void 0, function* () {
    const metrics = yield measureBuildStats(log, buildConfig, verbose);
    yield writeBuildStats(log, buildConfig, metrics);
});
//# sourceMappingURL=index.js.map