import * as tslib_1 from "tslib";
import { load } from 'cheerio';
import { getSequenceAverage } from '../util/math';
import { formatTimeMs, timeout } from '../util/time';
import { loadSSRPage, runStatsOnServer } from './server';
const ssrStats = (log, buildConfig, verbose = false) => tslib_1.__awaiter(this, void 0, void 0, function* () {
    if (!buildConfig.HAS_SERVER) {
        log.info('Skipping SSR stats because the application has no server');
        return {};
    }
    log.info('Measuring SSR load times...');
    const stats = {};
    try {
        yield runStatsOnServer(log, buildConfig, ({ page, url }) => tslib_1.__awaiter(this, void 0, void 0, function* () {
            const loadPage = () => timeout(loadSSRPage(url), 20000);
            const { size, content } = yield loadPage();
            if (verbose) {
                log.info(`### SSR content for ${url}`);
                log.info('---------------------');
                log.info(content);
                log.info('---------------------');
            }
            const domSize = load(content)('*').length;
            const time = yield getSequenceAverage(log, () => tslib_1.__awaiter(this, void 0, void 0, function* () {
                const result = yield loadPage();
                return result.time;
            }), 5);
            stats[`${page}_ssr_document_size`] = size.toFixed(0);
            stats[`${page}_ssr_dom_size`] = domSize.toString();
            stats[`${page}_ssr_loadtime`] = formatTimeMs(time);
        }), verbose);
        log.info({ stats }, `SSR stats`);
        return stats;
    }
    catch (err) {
        log.error({ err }, 'Error measuring SSR stats');
        return {};
    }
});
export default ssrStats;
//# sourceMappingURL=ssr-stats.js.map