import { fork, spawn } from 'child_process';
// make sure all child processes are killed when the process exits
// https://stackoverflow.com/questions/15833047/how-to-kill-all-child-processes-on-exit
let childProcesses = [];
const killAllChildProcesses = () => {
    childProcesses.forEach(proc => {
        try {
            proc.kill();
            // tslint:disable-next-line:no-empty
        }
        catch (err) { }
    });
    childProcesses = [];
};
process.on('exit', killAllChildProcesses);
process.on('SIGINT', () => process.exit());
process.on('SIGTERM', () => process.exit());
export const spawnPromise = (log, command, args, options, longRunning = false) => new Promise((resolve, reject) => {
    log.info(`[pwt] ${command} ${args.join(' ')}`);
    const proc = spawn(command, args, options);
    proc.on('exit', code => {
        if (code === 0) {
            resolve(proc);
        }
        else {
            reject(code);
        }
    });
    proc.on('error', err => reject(err));
    if (longRunning) {
        setTimeout(() => resolve(proc), 1000);
    }
    childProcesses.push(proc);
});
export const forkPromise = (log, command, args, options, longRunning = false) => new Promise((resolve, reject) => {
    log.info(`[pwt] node ${options && options.execArgv ? `${options.execArgv.join(' ')} ` : ''}${command} ${args.join(' ')}`);
    const proc = fork(command, args, options);
    proc.on('exit', code => {
        if (code === 0) {
            resolve(proc);
        }
        else {
            reject(code);
        }
    });
    proc.on('error', err => reject(err));
    if (longRunning) {
        setTimeout(() => resolve(proc), 1000);
    }
    childProcesses.push(proc);
});
//# sourceMappingURL=process.js.map