import * as tslib_1 from "tslib";
import { fork } from 'child_process';
import dotenv from 'dotenv';
import express from 'express';
import proxyMiddleware from 'http-proxy-middleware';
import path from 'path';
import webpack from 'webpack';
import { getWebpackConfig } from '../build/build';
import { getPort } from '../runtime/server/server';
import { findFreePort, waitForConnection } from '../runtime/util/network';
import { getHotReloadMiddleware, openBrowser } from '../server/dev';
const restartServer = (buildConfig, port, projectDir, oldServer) => {
    if (oldServer) {
        oldServer.kill();
    }
    // When running in local dev, we have a different process.cwd() than
    // when running in production. This allows static files and such to resolve
    return fork(path.resolve(buildConfig.OUTPUT, 'server.js'), [], {
        env: Object.assign({}, process.env, { LOAD_DEFAULT_ASSETS: true, PORT: port, PROJECT_DIR: projectDir }),
    });
};
const watchServer = (log, buildConfig) => new Promise((resolve) => tslib_1.__awaiter(this, void 0, void 0, function* () {
    dotenv.config({
        path: path.join(buildConfig.BASE, '.env'),
    });
    const hostPort = yield findFreePort(getPort(buildConfig.DEV_SERVER_PORT));
    const devServerPort = yield findFreePort(hostPort + 1);
    let devServer;
    let devServerAvailable;
    const serverCompiler = webpack(getWebpackConfig(log, buildConfig, 'server', 'dev'));
    serverCompiler.hooks.invalid.tap('invalid', () => {
        log.info('🦄 Server changed, rebuilding and restarting server...⭐');
    });
    const watching = serverCompiler.watch({
        aggregateTimeout: 10000,
    }, () => {
        if (!devServer) {
            setTimeout(() => openBrowser(hostPort), 2000);
        }
        devServer = restartServer(buildConfig, devServerPort, buildConfig.BASE, devServer);
        setTimeout(() => {
            devServerAvailable = waitForConnection(devServerPort);
        }, 100);
    });
    const app = express();
    app.use(getHotReloadMiddleware(log, buildConfig));
    app.use((_req, _res, next) => tslib_1.__awaiter(this, void 0, void 0, function* () {
        yield devServerAvailable;
        next();
    }));
    app.use(proxyMiddleware('http://localhost:' + devServerPort));
    const server = app.listen(hostPort, () => {
        resolve({
            app,
            close: () => {
                return Promise.all([
                    new Promise(closeResolve => watching.close(() => {
                        closeResolve();
                    })),
                    new Promise(closeResolve => server.close(() => closeResolve())),
                ]).then(() => {
                    if (devServer) {
                        devServer.kill();
                    }
                });
            },
            server,
        });
    });
    app.set('server', server);
}));
export default watchServer;
//# sourceMappingURL=server.js.map