var _this = this;
import * as tslib_1 from "tslib";
import path from 'path';
import SpeedMeasurePlugin from 'speed-measure-webpack-plugin';
import { ENVIRONMENTS, getWebpackConfig, TARGETS } from '../build/build';
import clean from '../clean';
import { watchtowerConfigFilename } from '../runtime/config/config';
import { writeFile } from '../runtime/util/fs';
import { webpackPromise } from '../util/webpack';
import { getMd5, setupWithBuildInfo, TSCONFIG_VALIDATION_ITEM, validateCache, } from './cache-validator';
export function smp(buildConfig, webpackConfig) {
    var smpPlugin = new SpeedMeasurePlugin();
    return buildConfig.SMP ? smpPlugin.wrap(webpackConfig) : webpackConfig;
}
var buildTarget = function (log, buildConfig, target, environment) {
    if (environment === void 0) { environment = 'prod'; }
    return tslib_1.__awaiter(_this, void 0, void 0, function () {
        var config, disableCaching, webpackConfigString, configHash;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    config = getWebpackConfig(log, buildConfig, target, environment);
                    if (!config) {
                        return [2 /*return*/, Promise.reject("Could not load webpack configuration for " + target + "/" + environment + "!")];
                    }
                    disableCaching = String(process.env.BUILD_CACHE_DISABLED).toLowerCase() === 'true';
                    if (!disableCaching) return [3 /*break*/, 1];
                    log.info("Build Caching Disabled... BUILD_CACHE_DISABLED=" + disableCaching);
                    return [3 /*break*/, 4];
                case 1:
                    if (!(process.env.NODE_ENV !== 'test' && !disableCaching)) return [3 /*break*/, 4];
                    webpackConfigString = JSON.stringify(config);
                    return [4 /*yield*/, getMd5(log, 'webpackConfig', webpackConfigString)];
                case 2:
                    configHash = _a.sent();
                    setupWithBuildInfo(log, {
                        buildInfo: {
                            environment: environment,
                            project: buildConfig.BASE,
                            target: target,
                        },
                        traceMessages: false,
                        validationItems: [
                            TSCONFIG_VALIDATION_ITEM,
                            { isFile: false, itemHash: configHash, hashKey: 'webpackConfig' },
                        ],
                    });
                    return [4 /*yield*/, validateCache(log)];
                case 3:
                    _a.sent();
                    _a.label = 4;
                case 4: return [2 /*return*/, webpackPromise(log, smp(buildConfig, config)).then(function () {
                        var runtimeConfig = {
                            ASSETS_PATH: buildConfig.ASSETS_PATH_PREFIX,
                            ASSETS_PATH_PREFIX: buildConfig.ASSETS_PATH_PREFIX,
                            BASE: '.',
                            PUBLIC_PATH: buildConfig.PUBLIC_PATH,
                            SERVER_PUBLIC_DIR: buildConfig.SERVER_PUBLIC_DIR === false ? false : 'public/',
                        };
                        // On success write out watchtower config
                        return writeFile(log, path.join(buildConfig.OUTPUT, watchtowerConfigFilename), JSON.stringify(runtimeConfig, undefined, 2));
                    })];
            }
        });
    });
};
var getBuildEnvironment = function (args) {
    for (var _i = 0, args_1 = args; _i < args_1.length; _i++) {
        var arg = args_1[_i];
        if (typeof arg !== 'string') {
            continue;
        }
        if (ENVIRONMENTS.indexOf(arg) !== -1) {
            return arg;
        }
    }
    return 'prod';
};
var getBuildTargets = function (buildConfig, args) {
    for (var _i = 0, args_2 = args; _i < args_2.length; _i++) {
        var arg = args_2[_i];
        if (!buildConfig.HAS_SERVER && arg === 'server') {
            continue;
        }
        if (typeof arg !== 'string') {
            continue;
        }
        if (TARGETS.indexOf(arg) !== -1) {
            return [arg];
        }
    }
    var defaultTargets = buildConfig.HAS_SERVER ? ['server', 'client'] : ['client'];
    return defaultTargets;
};
/**
 * Builds one or all targets in a specified environment
 * @param args
 *  [<target>] [<environment>] [-p <project root>]
 *  - target defaults to both server and client
 *  - environment defaults to prod
 *  - p: the root of the build, used for config discovery
 */
var build = function (log, buildConfig) {
    var args = [];
    for (var _i = 2; _i < arguments.length; _i++) {
        args[_i - 2] = arguments[_i];
    }
    return tslib_1.__awaiter(_this, void 0, void 0, function () {
        var targets, environment, cleanTarget, _a, targets_1, target;
        return tslib_1.__generator(this, function (_b) {
            switch (_b.label) {
                case 0:
                    targets = getBuildTargets(buildConfig, args);
                    environment = getBuildEnvironment(args);
                    cleanTarget = buildConfig.OUTPUT;
                    return [4 /*yield*/, clean(log, cleanTarget)];
                case 1:
                    _b.sent();
                    _a = 0, targets_1 = targets;
                    _b.label = 2;
                case 2:
                    if (!(_a < targets_1.length)) return [3 /*break*/, 5];
                    target = targets_1[_a];
                    return [4 /*yield*/, buildTarget(log, buildConfig, target, environment)];
                case 3:
                    _b.sent();
                    _b.label = 4;
                case 4:
                    _a++;
                    return [3 /*break*/, 2];
                case 5: return [2 /*return*/];
            }
        });
    });
};
export default build;
//# sourceMappingURL=build.js.map