import { Logger } from 'typescript-log';
import { BuildEnvironment, BuildTarget } from '../../lib/types';
declare type ValidationItem = {
    isFile: true;
    filePath: string;
    hashKey: string;
} | {
    isFile: false;
    itemHash: string;
    hashKey: string;
};
interface CacheLoaderValidation {
    cacheValidationConfigPath: string;
    cacheDirectory: string;
    validationItems: ValidationItem[];
}
interface CacheLoaderValidationFile {
    [key: string]: string | boolean;
    cacheCleared: boolean;
}
interface BuildInfo {
    project: string;
    environment: BuildEnvironment;
    target: BuildTarget;
}
export declare const TSCONFIG_VALIDATION_ITEM: ValidationItem;
export declare const setup: (log: Logger, options: {
    cacheDirectory?: string | undefined;
    validationItems?: ValidationItem[] | undefined;
    valiationConfigPath?: string | undefined;
    traceMessages?: boolean | undefined;
}) => CacheLoaderValidation & {
    baseCacheDirectory: string;
};
export declare const setupWithBuildInfo: (log: Logger, options: {
    cacheDirectory?: string | undefined;
    validationItems?: ValidationItem[] | undefined;
    buildInfo: BuildInfo;
    traceMessages?: boolean | undefined;
}) => CacheLoaderValidation & {
    baseCacheDirectory: string;
};
export declare const buildCacheDirectory: (buildInfo: BuildInfo) => string;
export declare const getConfigContents: (log: Logger, configFilePath: string) => Promise<CacheLoaderValidationFile | null>;
export declare const deletePath: (log: Logger, fileOrDir: string) => Promise<void>;
export declare const getMd5: (log: Logger, key: string, item: string) => Promise<string>;
/**
 * Determines if the build cache should be cleared if the ts config has changed.
 */
export declare const validateCache: (log: Logger) => Promise<void>;
export declare const writeDummyConfigFile: (log: Logger, file: string, config: CacheLoaderValidationFile) => Promise<void>;
export declare const writeDummyFile: (log: Logger, file: string, contents: string) => Promise<void>;
export {};
