import AssetsPlugin from 'assets-webpack-plugin';
import fs from 'fs';
import HtmlWebpackPlugin from 'html-webpack-plugin';
import path from 'path';
import { getAssetsFile } from '../runtime/server';
import { updateAssetLocations } from '../runtime/server/assets';
var getPlugins = function (buildConfig) { return [
    new AssetsPlugin({
        filename: path.relative(process.cwd(), getAssetsFile(buildConfig.OUTPUT)),
        processOutput: function (assets) {
            updateAssetLocations(assets);
            return JSON.stringify(assets);
        },
    }),
]; };
/**
 * Base webpack config for the client that is used both in development and production
 * - Compile SCSS to CSS and extract into external assets
 * - Create assets.json that maps the created assets to their locations
 * - Create vendor chunk with everything from node_modules except for SWM modules
 */
var clientBaseConfig = function (options) {
    var _a = options.buildConfig, CLIENT_ENTRY = _a.CLIENT_ENTRY, OUTPUT = _a.OUTPUT, CLIENT_POLYFILLS = _a.CLIENT_POLYFILLS, PUBLIC_PATH = _a.PUBLIC_PATH, SERVER_PUBLIC_DIR = _a.SERVER_PUBLIC_DIR;
    var mainEntry = [CLIENT_ENTRY];
    /*
        https://github.com/webpack/webpack/issues/6647
        You should not have a entrypoint for vendor. It's not an entry.
        If you want to run two modules in order at an entrypoint, use an array.
    */
    if (CLIENT_POLYFILLS && fs.existsSync(CLIENT_POLYFILLS)) {
        mainEntry = [CLIENT_POLYFILLS, CLIENT_ENTRY];
    }
    var entry = {
        main: mainEntry,
    };
    var plugins = getPlugins(options.buildConfig);
    if (SERVER_PUBLIC_DIR) {
        var indexHtml = path.resolve(SERVER_PUBLIC_DIR, 'index.html');
        if (fs.existsSync(indexHtml)) {
            plugins.push(new HtmlWebpackPlugin({
                inject: true,
                template: indexHtml,
            }));
        }
    }
    return {
        entry: entry,
        module: {
            rules: [],
        },
        optimization: {
            splitChunks: {
                cacheGroups: {
                    vendor: {
                        chunks: 'all',
                        name: 'vendor',
                        priority: -20,
                        test: function (module) {
                            if (!module.context) {
                                return false;
                            }
                            var modulePos = module.context.indexOf('node_modules');
                            if (modulePos === -1) {
                                return false;
                            }
                            var isWatchtower = module.context.indexOf('project-watchtower', modulePos) !== -1;
                            return !isWatchtower;
                        },
                    },
                },
            },
        },
        output: {
            path: OUTPUT,
            publicPath: PUBLIC_PATH,
        },
        plugins: plugins,
    };
};
export default clientBaseConfig;
//# sourceMappingURL=webpack.client.js.map