import fs from 'fs';
import path from 'path';
var assets;
var assetsLoaded = false;
export var getAssetsFile = function (base) { return path.resolve(base, 'assets.json'); };
var ensureAssets = function (runtimeConfig) {
    if (assetsLoaded) {
        return;
    }
    var assetsFile = getAssetsFile(runtimeConfig.BASE);
    try {
        var assetsFileContents = fs.readFileSync(assetsFile);
        assets = JSON.parse(assetsFileContents.toString());
        assetsLoaded = true;
    }
    catch (e) {
        throw new Error("Cannot read assets file from " + assetsFile);
    }
};
export var setDefaultAssets = function (buildConfig) {
    // When running in dev mode, we don't use assets.json so we need to prime
    // the assets location
    updateAssetLocations({
        main: {
            css: buildConfig.PUBLIC_PATH + buildConfig.ASSETS_PATH_PREFIX + 'css/main.css',
            js: buildConfig.PUBLIC_PATH + buildConfig.ASSETS_PATH_PREFIX + 'js/main.js',
        },
        vendor: {
            js: buildConfig.PUBLIC_PATH + buildConfig.ASSETS_PATH_PREFIX + 'js/vendor.js',
        },
    });
};
export function updateAssetLocations(newAssets) {
    assets = newAssets;
    assetsLoaded = true;
}
export function getAssetLocations(runtimeConfig) {
    ensureAssets(runtimeConfig);
    return assets;
}
export function getAssets(runtimeConfig) {
    ensureAssets(runtimeConfig);
    return assets;
}
export var getAbsoluteAssetPath = function (runtimeConfig, asset) {
    var staticPath = runtimeConfig.PUBLIC_PATH + runtimeConfig.ASSETS_PATH_PREFIX;
    var relativeAsset = asset.slice(staticPath.length);
    if (relativeAsset[0] === '/') {
        relativeAsset = relativeAsset.slice(1);
    }
    return path.resolve(runtimeConfig.ASSETS_PATH, relativeAsset);
};
export function getHeadAssets(buildAssets) {
    return Object.keys(buildAssets)
        .filter(function (chunkName) {
        var chunk = buildAssets[chunkName];
        return chunk.css;
    })
        .map(function (chunkName) { return ({
        tag: "<link id=\"css-main\" type=\"text/css\" rel=\"stylesheet\" href=\"" + buildAssets[chunkName].css + "\">",
    }); });
}
export function getBodyAssets(buildAssets) {
    var chunkNames = Object.keys(buildAssets)
        // Filter assets which are not .js and not main/vendor
        .filter(function (chunkName) {
        if (chunkName === 'main' || chunkName === 'vendor' || chunkName === 'manifest') {
            return false;
        }
        var chunk = buildAssets[chunkName];
        return !!chunk.js;
    });
    return ['manifest', 'vendor'].concat(chunkNames, ['main']).filter(function (chunkName) { return buildAssets[chunkName]; })
        .reduce(function (acc, chunkName) {
        // Turns out, webpack types are wrong, can be an array
        var jsAsset = buildAssets[chunkName].js;
        if (Array.isArray(jsAsset)) {
            acc.push.apply(acc, jsAsset.map(function (file) { return ({
                tag: "<script src=\"" + file + "\"></script>",
            }); }));
        }
        else {
            acc.push({
                tag: "<script src=\"" + buildAssets[chunkName].js + "\"></script>",
            });
        }
        return acc;
    }, []);
}
//# sourceMappingURL=assets.js.map