import fs from 'fs';
import path from 'path';
import { getAssets, getBodyAssets, getHeadAssets } from '../assets';
import { PromiseTracker } from '../ssr/full-render';
import { renderHtml } from '../ssr/helpers/render-html';
var isProduction = process.env.NODE_ENV === 'production';
export var expressNoop = function (_res, _req, next) { return next(); };
export var getDefaultHtmlMiddleware = function (log, runtimeConfig) {
    // on production we just serve the generated index.html
    if (isProduction) {
        var indexPath_1 = path.resolve(runtimeConfig.BASE, 'index.html');
        var indexFileMissing_1 = !fs.existsSync(indexPath_1);
        var loggedMissingIndexFileError_1 = false;
        var productionMiddleware = function (_req, res) {
            // We only log the error if we hit this middleware
            // if the consumer has registered their own SSR middleware we will
            // never use this, so no need to log an error
            if (indexFileMissing_1) {
                if (!loggedMissingIndexFileError_1) {
                    log.error('Cannot find index.html file to serve, default watchtower middleware will return 404');
                    loggedMissingIndexFileError_1 = true;
                }
                return res.status(404);
            }
            return res.status(200).sendFile(indexPath_1);
        };
        return productionMiddleware;
    }
    // for development we grab the source index.html and add the assets
    var indexContent;
    if (runtimeConfig.SERVER_PUBLIC_DIR) {
        var indexPath = path.resolve(runtimeConfig.SERVER_PUBLIC_DIR, 'index.html');
        if (fs.existsSync(indexPath)) {
            indexContent = fs.readFileSync(indexPath, 'utf8');
        }
    }
    var middleware = function (req, res) {
        var buildAssets = getAssets(runtimeConfig);
        if (indexContent) {
            var withHeadTags = indexContent.replace('</head>', getHeadAssets(buildAssets)
                .map(function (headAsset) { return headAsset.tag; })
                .join('\n') + "\n    </head>");
            var withBodyTags = withHeadTags.replace('</body>', getBodyAssets(buildAssets)
                .map(function (bodyAsset) { return bodyAsset.tag; })
                .join('\n') + "\n    </body>");
            return res
                .status(200)
                .contentType('text/html')
                .send(withBodyTags);
        }
        var indexWithAssets = renderHtml({
            context: {
                promiseTracker: new PromiseTracker(),
                ssrRequestProps: {},
            },
            head: undefined,
            pageTags: {
                body: getBodyAssets(buildAssets),
                head: getHeadAssets(buildAssets),
            },
            renderResult: '',
            req: req,
        });
        return res
            .status(200)
            .contentType('text/html')
            .send(indexWithAssets);
    };
    return middleware;
};
//# sourceMappingURL=default-html-middleware.js.map