/// <reference types="react" />
import { Assets } from 'assets-webpack-plugin';
import { Express, Request, RequestHandler } from 'express';
import { HelmetData } from 'react-helmet';
import { Logger } from 'typescript-log';
import { PromiseTracker } from '../../util/promise-tracker';
import { PageTags } from './';
import { PageTag } from './full-render';
export interface RenderContext<SSRRequestProps = object> {
    /** This holds the app state which needs to be kept between SSR
     * passes. It is essentially a state bag, it could include a redux store,
     * or any other state store which needs to persist between render passes
     */
    ssrRequestProps: SSRRequestProps;
    promiseTracker: PromiseTracker;
}
export declare type RenderApp<SSRRequestProps extends object> = (params: {
    log: Logger;
    context: RenderContext<SSRRequestProps>;
    req: Request;
}) => JSX.Element;
export interface RenderHtmlParams<SSRRequestProps extends object, RenderResult> {
    head: HelmetData | undefined;
    renderResult: RenderResult;
    pageTags: PageTags;
    context: RenderContext<SSRRequestProps>;
    req: Request;
}
export declare type RenderHtml<SSRRequestProps extends object, RenderResult> = (params: RenderHtmlParams<SSRRequestProps, RenderResult>) => string;
export declare type CreatePageTags<SSRRequestProps> = (options: {
    buildAssets: Assets;
    helmetTags: string[];
    stateTransfers: PageTag[];
    renderContext: RenderContext<SSRRequestProps>;
}) => PageTags;
export interface ServerSideRenderMiddlewareOptions<SSRRequestProps extends object, RenderResult> {
    app: Express & {
        log: Logger;
    };
    ssrTimeoutMs: number;
    setupRequest: (req: Request, promiseTracker: PromiseTracker) => Promise<SSRRequestProps>;
    renderApp: RenderApp<SSRRequestProps>;
    renderHtml: RenderHtml<SSRRequestProps, RenderResult>;
    errorLocation: string;
    createPageTags?: CreatePageTags<SSRRequestProps>;
    pageNotFoundLocation: string;
    renderFn?: (element: React.ReactElement<any>) => RenderResult;
}
export declare const createSsrMiddleware: <SSRRequestProps extends object, RenderResult = string>(options: ServerSideRenderMiddlewareOptions<SSRRequestProps, RenderResult>) => RequestHandler;
