var _this = this;
import * as tslib_1 from "tslib";
import { renderToString } from 'react-dom/server';
import URL from 'url';
import { getRuntimeConfig } from '../../config/config';
import { PromiseTracker } from '../../util/promise-tracker';
import { getAssetLocations, getBodyAssets, getHeadAssets } from '../assets';
import { hasLog } from '../middleware/ensure-request-log-middleware';
import { renderPageContents, ServerRenderResultType, transferState, } from './';
export var createSsrMiddleware = function (options) {
    var runtimeConfig = getRuntimeConfig(options.app.log);
    var buildAssets = getAssetLocations(runtimeConfig);
    return function (req, response, next) { return tslib_1.__awaiter(_this, void 0, void 0, function () {
        var promiseTracker, appState, renderContext, ssrOptions, pageRenderResult, createPageMarkup;
        var _this = this;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    if (!hasLog(req)) {
                        // tslint:disable-next-line:no-console
                        console.error('Skipping SSR middleware due to missing req.log key');
                        return [2 /*return*/, next()];
                    }
                    promiseTracker = new PromiseTracker();
                    return [4 /*yield*/, options.setupRequest(req, promiseTracker)];
                case 1:
                    appState = _a.sent();
                    ssrOptions = {
                        appRender: function () {
                            renderContext = {
                                promiseTracker: promiseTracker,
                                ssrRequestProps: appState,
                            };
                            return options.renderApp({
                                context: renderContext,
                                log: req.log,
                                req: req,
                            });
                        },
                        errorLocation: options.errorLocation,
                        events: {
                            // tslint:disable-next-line:no-empty
                            renderPerformed: function () { },
                        },
                        log: req.log,
                        pageNotFoundLocation: options.pageNotFoundLocation,
                        // Not perfect typings, if someone specifies the render result type
                        // as something it isn't, that's their own fault
                        renderFn: options.renderFn || renderToString,
                        resetRequest: function (location) { return tslib_1.__awaiter(_this, void 0, void 0, function () {
                            return tslib_1.__generator(this, function (_a) {
                                switch (_a.label) {
                                    case 0:
                                        req.url = location;
                                        req.query = URL.parse(req.url, true).query;
                                        return [4 /*yield*/, options.setupRequest(req, promiseTracker)];
                                    case 1:
                                        appState = _a.sent();
                                        return [2 /*return*/];
                                }
                            });
                        }); },
                        ssrTimeoutMs: options.ssrTimeoutMs,
                    };
                    return [4 /*yield*/, renderPageContents(appState, ssrOptions, req.url, promiseTracker)];
                case 2:
                    pageRenderResult = _a.sent();
                    createPageMarkup = function (result) {
                        var helmetTags = [];
                        if (result.head && result.head.title) {
                            helmetTags.push(result.head.title.toString());
                        }
                        if (result.head && result.head.base) {
                            helmetTags.push(result.head.base.toString());
                        }
                        if (result.head && result.head.script) {
                            helmetTags.push(result.head.script.toString());
                        }
                        if (result.head && result.head.meta) {
                            helmetTags.push(result.head.meta.toString());
                        }
                        if (result.head && result.head.link) {
                            helmetTags.push(result.head.link.toString());
                        }
                        var stateTransfers = [];
                        // When watchtower renders an error, the client needs to know
                        // so it can hydrate the error location. The WatchtowerBrowserRouter takes
                        // care of this
                        if (result.renderLocation !== req.originalUrl) {
                            stateTransfers.push({
                                tag: transferState('watchtower_hydrate_location', result.renderLocation),
                            });
                        }
                        var pageTags = options.createPageTags
                            ? options.createPageTags({ buildAssets: buildAssets, helmetTags: helmetTags, stateTransfers: stateTransfers, renderContext: renderContext })
                            : {
                                body: getBodyAssets(buildAssets).slice(),
                                head: helmetTags.map(function (tag) { return ({ tag: tag }); }).concat(getHeadAssets(buildAssets), stateTransfers),
                            };
                        return options.renderHtml({
                            context: renderContext,
                            head: result.head,
                            pageTags: pageTags,
                            renderResult: result.renderedContent,
                            req: req,
                        });
                    };
                    switch (pageRenderResult.type) {
                        case ServerRenderResultType.Success:
                            response
                                .status(pageRenderResult.statusCode)
                                .header('Content-Type', 'text/html')
                                .send(createPageMarkup(pageRenderResult));
                            return [2 /*return*/];
                        case ServerRenderResultType.Redirect:
                            response.redirect(pageRenderResult.isPermanent ? 301 : 302, pageRenderResult.redirectTo);
                            return [2 /*return*/];
                        case ServerRenderResultType.Failure:
                        default:
                            // tslint:disable-line:no-switch-case-fall-through
                            response.status(500).send();
                    }
                    return [2 /*return*/];
            }
        });
    }); };
};
//# sourceMappingURL=create-middleware.js.map