/// <reference types="react" />
import { Logger } from 'typescript-log';
import { PromiseTracker } from '../../universal';
import { CreateAppElement } from './render-app-to-string';
import { WatchtowerEvents } from './render-events';
import * as ServerRenderResults from './server-render-results';
export { PromiseTracker };
export interface RenderOptions<RenderResult> {
    log: Logger;
    errorLocation: string;
    pageNotFoundLocation: string;
    appRender: CreateAppElement;
    events?: WatchtowerEvents;
    renderFn: (element: React.ReactElement<any>) => RenderResult;
}
export interface ServerSideRenderOptions<RenderResult> extends RenderOptions<RenderResult> {
    ssrTimeoutMs: number;
    /** Used when the request url is re-written to reset the SSR request state */
    resetRequest: (location: string) => Promise<any>;
}
export interface PageTag {
    /** The html tag to insert into the rendered html */
    tag: string;
}
export interface PageTags {
    head: PageTag[];
    body: PageTag[];
}
export declare function renderPageContents<SSRRequestProps extends object, RenderResult>(ssrRequestProps: SSRRequestProps, options: ServerSideRenderOptions<RenderResult>, location: string, promiseTracker: PromiseTracker): Promise<ServerRenderResults.ServerRenderResult<SSRRequestProps, RenderResult>>;
