import * as tslib_1 from "tslib";
var delay = function (forMs) { return new Promise(function (resolve) { return setTimeout(resolve, forMs); }); };
var component = 'RecursiveTaskResolver';
var timedOut = Symbol('Timed out');
function innerResolve(log, promiseTracker, render, location, initialRender, numberAttempts, remainingAttempts, timeoutPromise) {
    if (!promiseTracker.hasWork()) {
        log.debug({ component: component, location: location }, 'No work, resolving');
        return Promise.resolve(initialRender);
    }
    if (!remainingAttempts || remainingAttempts <= 0) {
        return Promise.reject(new Error("Abort waiting for loading all data after " + numberAttempts + " recursive waits"));
    }
    return new Promise(function (resolve, reject) {
        return setTimeout(function () {
            var promiseOrTimedOut = [promiseTracker.waitForCompletion(), timeoutPromise];
            Promise.race(promiseOrTimedOut)
                .then(function (p) {
                // If we have timed out return the timed out symbol to
                // prevent another nested render
                if (p === timedOut) {
                    return p;
                }
                log.debug({ component: component, location: location }, 'Re-rendering to trigger any child promises');
                var renderResult = render();
                // eslint-disable-next-line consistent-return
                return innerResolve(log, promiseTracker, render, location, renderResult, numberAttempts, remainingAttempts - 1, timeoutPromise);
            })
                .then(resolve)
                .catch(reject);
        });
    });
}
/**
 * Utility which will recursively render the React application, triggering any
 * additional data loader recursively until no more data loads are triggered
 * or it times out, or it hits the max depth
 */
export function recursiveTaskResolver(log, promiseTracker, render, location, initialRender, numberAttempts, timeoutMs) {
    return tslib_1.__awaiter(this, void 0, void 0, function () {
        var timeoutPromise, resolved;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    timeoutPromise = delay(timeoutMs).then(function () { return timedOut; });
                    return [4 /*yield*/, innerResolve(log, promiseTracker, render, location, initialRender, numberAttempts, numberAttempts, timeoutPromise)];
                case 1:
                    resolved = _a.sent();
                    if (resolved === timedOut) {
                        // Fall back to just rendering again
                        log.error({ location: location }, "Resolving tasks timed out after " + timeoutMs + "ms");
                        return [2 /*return*/, render()];
                    }
                    return [2 /*return*/, resolved];
            }
        });
    });
}
//# sourceMappingURL=recursive-task-resolver.js.map