var _this = this;
import * as tslib_1 from "tslib";
import fs from 'fs';
import lighthouse from 'lighthouse';
import path from 'path';
import { promisify } from 'util';
import { formatTimeMs, timeout } from '../util/time';
import { runStatsOnServer } from './server';
export var runLighthouse = function (log, url) { return tslib_1.__awaiter(_this, void 0, void 0, function () {
    var results, err_1;
    return tslib_1.__generator(this, function (_a) {
        switch (_a.label) {
            case 0:
                _a.trys.push([0, 2, , 3]);
                log.debug({ url: url }, 'Running lighthouse');
                return [4 /*yield*/, lighthouse(url, {
                        output: 'json',
                        // provided by build environment, ref OPS-383
                        port: Number(process.env.CHROME_REMOTE_DEBUGGING_PORT) || 9222,
                        skipAutolaunch: true,
                    }, {
                        extends: 'lighthouse:default',
                        settings: {},
                    })];
            case 1:
                results = _a.sent();
                return [2 /*return*/, results];
            case 2:
                err_1 = _a.sent();
                log.error({ err: err_1 }, 'Could not run lighthouse!');
                return [2 /*return*/, undefined];
            case 3: return [2 /*return*/];
        }
    });
}); };
export var lighthouseStats = function (log, buildConfig, verbose) {
    if (verbose === void 0) { verbose = false; }
    return tslib_1.__awaiter(_this, void 0, void 0, function () {
        var stats, lighthouseResult, err_2;
        var _this = this;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    if (!buildConfig.HAS_SERVER) {
                        log.info('Skipping lighthouse performance metrics because the application has no server');
                        return [2 /*return*/, {}];
                    }
                    log.info('Measuring lighthouse performance metrics...');
                    stats = {};
                    _a.label = 1;
                case 1:
                    _a.trys.push([1, 3, , 4]);
                    return [4 /*yield*/, runStatsOnServer(log, buildConfig, function (_a) {
                            var page = _a.page, url = _a.url;
                            return tslib_1.__awaiter(_this, void 0, void 0, function () {
                                var addLighthouseValue, category, domSize, key, statsKey, reportPath;
                                return tslib_1.__generator(this, function (_b) {
                                    switch (_b.label) {
                                        case 0: return [4 /*yield*/, timeout(runLighthouse(log, url), 120000)];
                                        case 1:
                                            lighthouseResult = _b.sent();
                                            addLighthouseValue = function (lighthouseKey, statsKey) {
                                                var result = lighthouseResult &&
                                                    lighthouseResult.lhr &&
                                                    lighthouseResult.lhr.audits &&
                                                    lighthouseResult.lhr.audits[lighthouseKey] &&
                                                    lighthouseResult.lhr.audits[lighthouseKey].rawValue;
                                                if (result !== undefined && result !== null) {
                                                    stats[page + "_" + statsKey] = formatTimeMs(+result);
                                                }
                                            };
                                            addLighthouseValue('first-contentful-paint', 'first_contentful_paint');
                                            addLighthouseValue('first-meaningful-paint', 'first_meaningful_paint');
                                            addLighthouseValue('first-cpu-idle', 'first_cpu_idle');
                                            addLighthouseValue('estimated-input-latency', 'estimated_input_latency');
                                            addLighthouseValue('interactive', 'interactive');
                                            addLighthouseValue('bootup-time', 'bootup_time');
                                            addLighthouseValue('network-requests', 'network_requests');
                                            addLighthouseValue('total-byte-weight', 'total_byte_weight');
                                            addLighthouseValue('speed-index', 'speed_index');
                                            if (!lighthouseResult) return [3 /*break*/, 3];
                                            for (category in lighthouseResult.lhr.categories) {
                                                if (lighthouseResult.lhr.categories.hasOwnProperty(category)) {
                                                    stats[page + "_category_" + category + "_score"] = (lighthouseResult.lhr.categories[category].score * 100).toFixed(0);
                                                }
                                            }
                                            if (lighthouseResult.lhr.audits['dom-size']) {
                                                domSize = lighthouseResult.lhr.audits['dom-size'];
                                                for (key in domSize.details.items) {
                                                    if (domSize.details.items.hasOwnProperty(key)) {
                                                        statsKey = domSize.details.items[key].statistic
                                                            .toLowerCase()
                                                            .replace(/ /g, '_');
                                                        stats[page + "_" + statsKey] = formatTimeMs(+domSize.details.items[key].value);
                                                    }
                                                }
                                            }
                                            reportPath = path.resolve(buildConfig.BASE, "lighthouse-report_" + page + ".json");
                                            log.info("Lighthouse results written to '" + reportPath + "', you can view them visually at https://googlechrome.github.io/lighthouse/viewer/");
                                            return [4 /*yield*/, promisify(fs.writeFile)(reportPath, lighthouseResult.report)];
                                        case 2:
                                            _b.sent();
                                            _b.label = 3;
                                        case 3:
                                            log.info({ stats: stats }, "Lighthouse stats");
                                            return [2 /*return*/];
                                    }
                                });
                            });
                        }, verbose)];
                case 2:
                    _a.sent();
                    return [2 /*return*/, stats];
                case 3:
                    err_2 = _a.sent();
                    log.error({ err: err_2 }, 'Error measuring lighthouse stats');
                    throw new Error('Error measuring lighthouse stats');
                case 4: return [2 /*return*/];
            }
        });
    });
};
//# sourceMappingURL=lighthouse.js.map