var _this = this;
import * as tslib_1 from "tslib";
import { load } from 'cheerio';
import { getSequenceAverage } from '../util/math';
import { formatTimeMs, timeout } from '../util/time';
import { loadSSRPage, runStatsOnServer } from './server';
var ssrStats = function (log, buildConfig, verbose) {
    if (verbose === void 0) { verbose = false; }
    return tslib_1.__awaiter(_this, void 0, void 0, function () {
        var stats, err_1;
        var _this = this;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    if (!buildConfig.HAS_SERVER) {
                        log.info('Skipping SSR stats because the application has no server');
                        return [2 /*return*/, {}];
                    }
                    log.info('Measuring SSR load times...');
                    stats = {};
                    _a.label = 1;
                case 1:
                    _a.trys.push([1, 3, , 4]);
                    return [4 /*yield*/, runStatsOnServer(log, buildConfig, function (_a) {
                            var page = _a.page, url = _a.url;
                            return tslib_1.__awaiter(_this, void 0, void 0, function () {
                                var loadPage, _b, size, content, domSize, time;
                                var _this = this;
                                return tslib_1.__generator(this, function (_c) {
                                    switch (_c.label) {
                                        case 0:
                                            loadPage = function () { return timeout(loadSSRPage(url), 20000); };
                                            return [4 /*yield*/, loadPage()];
                                        case 1:
                                            _b = _c.sent(), size = _b.size, content = _b.content;
                                            if (verbose) {
                                                log.info("### SSR content for " + url);
                                                log.info('---------------------');
                                                log.info(content);
                                                log.info('---------------------');
                                            }
                                            domSize = load(content)('*').length;
                                            return [4 /*yield*/, getSequenceAverage(log, function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
                                                    var result;
                                                    return tslib_1.__generator(this, function (_a) {
                                                        switch (_a.label) {
                                                            case 0: return [4 /*yield*/, loadPage()];
                                                            case 1:
                                                                result = _a.sent();
                                                                return [2 /*return*/, result.time];
                                                        }
                                                    });
                                                }); }, 5)];
                                        case 2:
                                            time = _c.sent();
                                            stats[page + "_ssr_document_size"] = size.toFixed(0);
                                            stats[page + "_ssr_dom_size"] = domSize.toString();
                                            stats[page + "_ssr_loadtime"] = formatTimeMs(time);
                                            return [2 /*return*/];
                                    }
                                });
                            });
                        }, verbose)];
                case 2:
                    _a.sent();
                    log.info({ stats: stats }, "SSR stats");
                    return [2 /*return*/, stats];
                case 3:
                    err_1 = _a.sent();
                    log.error({ err: err_1 }, 'Error measuring SSR stats');
                    return [2 /*return*/, {}];
                case 4: return [2 /*return*/];
            }
        });
    });
};
export default ssrStats;
//# sourceMappingURL=ssr-stats.js.map