import { fork, spawn } from 'child_process';
// make sure all child processes are killed when the process exits
// https://stackoverflow.com/questions/15833047/how-to-kill-all-child-processes-on-exit
var childProcesses = [];
var killAllChildProcesses = function () {
    childProcesses.forEach(function (proc) {
        try {
            proc.kill();
            // tslint:disable-next-line:no-empty
        }
        catch (err) { }
    });
    childProcesses = [];
};
process.on('exit', killAllChildProcesses);
process.on('SIGINT', function () { return process.exit(); });
process.on('SIGTERM', function () { return process.exit(); });
export var spawnPromise = function (log, command, args, options, longRunning) {
    if (longRunning === void 0) { longRunning = false; }
    return new Promise(function (resolve, reject) {
        log.info("[pwt] " + command + " " + args.join(' '));
        var proc = spawn(command, args, options);
        proc.on('exit', function (code) {
            if (code === 0) {
                resolve(proc);
            }
            else {
                reject(code);
            }
        });
        proc.on('error', function (err) { return reject(err); });
        if (longRunning) {
            setTimeout(function () { return resolve(proc); }, 1000);
        }
        childProcesses.push(proc);
    });
};
export var forkPromise = function (log, command, args, options, longRunning) {
    if (longRunning === void 0) { longRunning = false; }
    return new Promise(function (resolve, reject) {
        log.info("[pwt] node " + (options && options.execArgv ? options.execArgv.join(' ') + " " : '') + command + " " + args.join(' '));
        var proc = fork(command, args, options);
        proc.on('exit', function (code) {
            if (code === 0) {
                resolve(proc);
            }
            else {
                reject(code);
            }
        });
        proc.on('error', function (err) { return reject(err); });
        if (longRunning) {
            setTimeout(function () { return resolve(proc); }, 1000);
        }
        childProcesses.push(proc);
    });
};
//# sourceMappingURL=process.js.map