var _this = this;
import * as tslib_1 from "tslib";
import { fork } from 'child_process';
import dotenv from 'dotenv';
import express from 'express';
import proxyMiddleware from 'http-proxy-middleware';
import path from 'path';
import webpack from 'webpack';
import { getWebpackConfig } from '../build/build';
import { getPort } from '../runtime/server/server';
import { findFreePort, waitForConnection } from '../runtime/util/network';
import { getHotReloadMiddleware, openBrowser } from '../server/dev';
var restartServer = function (buildConfig, port, projectDir, oldServer) {
    if (oldServer) {
        oldServer.kill();
    }
    // When running in local dev, we have a different process.cwd() than
    // when running in production. This allows static files and such to resolve
    return fork(path.resolve(buildConfig.OUTPUT, 'server.js'), [], {
        env: tslib_1.__assign({}, process.env, { LOAD_DEFAULT_ASSETS: true, PORT: port, PROJECT_DIR: projectDir }),
    });
};
var watchServer = function (log, buildConfig) {
    return new Promise(function (resolve) { return tslib_1.__awaiter(_this, void 0, void 0, function () {
        var hostPort, devServerPort, devServer, devServerAvailable, serverCompiler, watching, app, server;
        var _this = this;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    dotenv.config({
                        path: path.join(buildConfig.BASE, '.env'),
                    });
                    return [4 /*yield*/, findFreePort(getPort(buildConfig.DEV_SERVER_PORT))];
                case 1:
                    hostPort = _a.sent();
                    return [4 /*yield*/, findFreePort(hostPort + 1)];
                case 2:
                    devServerPort = _a.sent();
                    serverCompiler = webpack(getWebpackConfig(log, buildConfig, 'server', 'dev'));
                    serverCompiler.hooks.invalid.tap('invalid', function () {
                        log.info('🦄 Server changed, rebuilding and restarting server...⭐');
                    });
                    watching = serverCompiler.watch({
                        aggregateTimeout: 10000,
                    }, function () {
                        if (!devServer) {
                            setTimeout(function () { return openBrowser(hostPort); }, 2000);
                        }
                        devServer = restartServer(buildConfig, devServerPort, buildConfig.BASE, devServer);
                        setTimeout(function () {
                            devServerAvailable = waitForConnection(devServerPort);
                        }, 100);
                    });
                    app = express();
                    app.use(getHotReloadMiddleware(log, buildConfig));
                    app.use(function (_req, _res, next) { return tslib_1.__awaiter(_this, void 0, void 0, function () {
                        return tslib_1.__generator(this, function (_a) {
                            switch (_a.label) {
                                case 0: return [4 /*yield*/, devServerAvailable];
                                case 1:
                                    _a.sent();
                                    next();
                                    return [2 /*return*/];
                            }
                        });
                    }); });
                    app.use(proxyMiddleware('http://localhost:' + devServerPort));
                    server = app.listen(hostPort, function () {
                        resolve({
                            app: app,
                            close: function () {
                                return Promise.all([
                                    new Promise(function (closeResolve) {
                                        return watching.close(function () {
                                            closeResolve();
                                        });
                                    }),
                                    new Promise(function (closeResolve) { return server.close(function () { return closeResolve(); }); }),
                                ]).then(function () {
                                    if (devServer) {
                                        devServer.kill();
                                    }
                                });
                            },
                            server: server,
                        });
                    });
                    app.set('server', server);
                    return [2 /*return*/];
            }
        });
    }); });
};
export default watchServer;
//# sourceMappingURL=server.js.map